# -*- coding: utf-8 -*-
"""

This is the gui where the spinboxes and checkboxes for controlling the mc daq live. Nevertheless, measurements are not
controlled from this Gui. It is more for searching and exploring the paremeters. 

@author: Usuario
"""
import sys
from PyQt5 import QtGui, QtCore
import qdarkstyle
import os
os.environ['PYQTGRAPH_QT_LIB'] = 'PyQt5'

from subclasses.controllayouts import LaserControlLayout
from subclasses.controllayouts import LaserScanLayout
from pyqtgraph import dockarea
from MCDAQcontrolsignals import anal_control_signal

class ControlGui(QtGui.QFrame):

	def __init__(self):
		super().__init__()
		self.initUI()

	def initUI(self):
		self.area = dockarea.DockArea()
		self.grid = QtGui.QGridLayout()
		self.grid.addWidget(self.area, 0, 0)
		self.setLayout(self.grid)

		self.dock_397 = dockarea.Dock('397', (100, 100))
		self.dock_866 = dockarea.Dock('866', (100, 100))
		
		self.area.addDock(self.dock_397)
		self.area.addDock(self.dock_866, 'left', self.dock_397)

		self.laser397_control_layout = LaserControlLayout('397', checkboxes=[], spinboxes = ['piezoA397', 'piezoB397'])
		self.laser397_scan_layout = LaserScanLayout(name='piezoA397', signal_to_scan_layout=self.laser397_control_layout)
		self.dock_397.addWidget(self.laser397_control_layout)
		self.dock_397.addWidget(self.laser397_scan_layout)
		
		self.laser866_control_layout = LaserControlLayout('866', checkboxes=[], spinboxes = ['piezoA866', 'piezoB866'])
		self.laser866_scan_layout = LaserScanLayout(name='piezoA866', signal_to_scan_layout=self.laser866_control_layout)
		self.dock_866.addWidget(self.laser866_control_layout)
		self.dock_866.addWidget(self.laser866_scan_layout)

		self.show()

	def make_connections(self, backend):
		# external connections
		scan_layout_list = [scan_layout for scan_layout in LaserScanLayout._registry if scan_layout.name == backend.name]
		for scan_layout in scan_layout_list:
			scan_layout.scanActionSignal.connect(backend.scan_action)
			backend.scanStepSignal.connect(scan_layout.scan_step)
			backend.scanEndSignal.connect(scan_layout.scan_end)


		
if __name__ == '__main__':
	app = QtGui.QApplication([])
	controlGui = ControlGui()
	piezoA397 = anal_control_signal('piezoA397', channel=0, ao_type='cavity_piezo', out_minimum = 0, out_maximum = 4)
	piezoB397 = anal_control_signal('piezoB397', channel=1, ao_type='cavity_piezo')
	piezoA866 = anal_control_signal('piezoA866', channel=2, ao_type='cavity_piezo', out_minimum = 0, out_maximum = 4)
	piezoB866 = anal_control_signal('piezoB866', channel=3, ao_type='cavity_piezo')



	mcDAQthread = QtCore.QThread()
	for ao in anal_control_signal._registry:
		controlGui.make_connections(ao)
		ao.make_connections(controlGui)
		ao.moveToThread(mcDAQthread)
		ao.scanTimer.moveToThread(mcDAQthread)
		ao.scanTimer.timeout.connect(ao.scan_event)

	mcDAQthread.start()

	sys.exit(app.exec_())